function [xvect,xdif,fx,nit,mol]=adptnewt(x0,tol,nmax,fun,dfun)
% ADPTNEW metodo di Newton adattivo.
% [ZERO,ITER,XVECT,XDIF,FX]=ADPTNEWT(FUN,DFUN,X0,TOL,NMAX) cerca lo
% zero di una funzione continua FUN nell'intervallo [A,B] usando il metodo di
% Newton adattivo e partendo da X0. TOL e NMAX specificano la tolleranza ed il
% massimo numero di iterazioni. FUN riceve in ingresso lo scalare x e restituisce
% un valore scalare reale. ZERO e` l'approssimazione della radice, ITER e` il numero
% di iterate svolte. XVECT e` il vettore delle iterate, XDIF il vettore delle differenze
% tra iterate successive, FX il vettore dei residui. MOL contiene il valore stimato
% della molteplicita` della radice
err=tol+1; iter=0; xdif=[]; mol=1; m=mol; r=1;
fx0=fun(x0); xvect=x0; fx=fx0;
while iter < nmax && err > tol
    fxx=fun(x0); f1x=dfun(x0);
    if f1x == 0
        fprintf(' Arresto causa annullamento derivata ');
        zero=[]; return
    end;
    x=x0-m(end)*fxx/f1x;
    err0=err; err=abs(x-x0); xdif=[xdif;err];
    xvect=[xvect;x]; x0=x; fx0=fun(x); fx=[fx;fx0];
    ra=err/err0; dif=abs(ra-r(end)); r=[r;ra];
    if dif < 1.e-3 && r(end) > 1.e-2
        mol=max(m(end),1/abs(1-r(end)));
    end
    m=[m;mol];
    iter=iter+1;
end
zero=xvect(end);
return
