function [x,k,res]=arnoldimet(A,b,x0,m,tol)
% ARNOLDIMET metodo di Arnoldi.
% [X,K,RES]=ARNOLDIMET(A,B,X0,M,TOL) risolve il sistema A*X=B
% con il metodo di Arnoldi. X0 e` il vettore iniziale, M specifica la massima dimensione
% del sottospazio di Krylov. TOL specifica la tolleranza del metodo. K e` il numero di
% iterazioni effettuate. RES e` un vettore contenente i residui
r0=b-A*x0;  nr0=norm(r0);
res=[]; norma_res=tol+1;
if nr0 == 0
    x=x0;
else
   v1=r0/nr0; V=v1; H=[]; k=0;
   while k <= m-1 && norma_res > tol
     [k,V,H] = gsarnoldi(A,m,k,V,H);
     [nr,nc]=size(H); e1=zeros(nc,1);e1(1)=1;
     z=(H(1:nc,:) \ e1) *nr0;
     norma_res = H(nr,nc)*abs(z(nc));
     res=[res;norma_res];
   end
   x=x0+V(:,1:nc)*z;
end
