function [x,uh] = ellfem(Nx,I,alpha,beta,gamma,f,bc,stabfun)
% ELLFEM risolutore ad elementi finiti lineari.
% [X,UH]=ELLFEM(NX,I,ALPHA,BETA,GAMMA,F,BC,STABFUN) risolve il
% problema ai limiti:
% -ALPHA*U''+BETA*U'+GAMMA=F in (I(1),I(2))
% U(I(1))=BC(1),       U(I(2))=BC(2)
% con elementi finiti lineari. Se STABFUN e` passata in input,
%si utilizza un metodo ad elementi finiti stabilizzato.
a=I(1); b=I(2); h=(b-a)/Nx; x=(a+h/2:h:b-h/2)';
alpha1=alpha(x); beta1=beta(x); gamma1=gamma(x);
f1=f(x);
rhs=0.5*h*(f1(1:Nx-1)+f1(2:Nx));
if nargin == 8
    [Afe,rhsbc]=femmatr(Nx,h,alpha1,beta1,gamma1,stabfun);
else
    [Afe,rhsbc]=femmatr(Nx,h,alpha1,beta1,gamma1);
end
[L,U,P]=lu(Afe);
rhs(1)=rhs(1)-bc(1)*(-alpha1(1)/h-beta1(1)/2+h*gamma1(1)/3+rhsbc(1));
rhs(Nx-1)=rhs(Nx-1)-bc(2)*(-alpha1(Nx)/h+beta1(Nx)/2+h*gamma1(Nx)/3+rhsbc(2));
rhs=P*rhs;
z=L \ rhs;
w=U \ z;
uh=[bc(1); w; bc(2)]; x=(a:h:b)';
return
