function [y1] = hermpol(x,y,dy,x1)
% HERMPOL interpolazione polinomiale di Hermite.
%  [Y1] = HERMPOL(X, Y, DY, X1) valuta il polinomio interpolatore di Hermite
%  di una funzione nei nodi memorizzati in X1. X contiene i nodi di interpolazione.
%  Y e DY contengono i valori della funzione e della sua derivata in X.
%  Y1 contiene i valori del polinomio interpolatore nei nodi X1.
n = length(x);  n1 = length(x1); y1 = zeros(size(x1));
for j = 1:n1
    xx = x1(j);
    for i = 1:n
        den = 1; num = 1; xn = x(i); derLi = 0;
        for k = 1:n
            if k ~= i
                num = num*(xx-x(k)); arg = xn-x(k);
                den = den*arg; derLi = derLi+1/arg;
            end
        end
        Lix2 = (num/den)^2; p = (1-2*(xx-xn)*derLi)*Lix2;
        q = (xx-xn)*Lix2;
        y1(j) = y1(j)+(y(i)*p+dy(i)*q);
    end
end
return
