function [L,U,P,Q]=lupivtot(A)
% LUPIVTOT fattorizzazione LU con pivotazione totale
% [L,U,P,Q]=LUPIVTOT(A) restituisce una matrice triangolare inferiore L
% con elementi diagonali pari a 1, una matrice triangolare superiore U
% e le matrici di permutazione P e Q, tali che P*A*Q=L*U.
[n,m]=size(A);
if n ~= m, error('Solo sistemi quadrati'); end
P=speye(n); Q=P; Minv=P; I=speye(n);
for k=1:n-1
    [Pk,Qk]=pivot(A,k,n,I);  A=Pk*A*Qk;
    [Mk,Mkinv]=MGauss(A,k,n);
    A=Mk*A;    P=Pk*P;     Q=Q*Qk;
    Minv=Minv*Pk*Mkinv;
end
U=triu(A); L=P*Minv;
return

function [Mk,Mkinv]=MGauss(A,k,n)
Mk=speye(n);
i=k+1:n;
Mk(i,k)=-A(i,k)/A(k,k);
Mkinv=2*speye(n)-Mk;
return

function [Pk,Qk]=pivot(A,k,n,I)
[y,i]=max(abs(A(k:n,k:n)));
[piv,jpiv]=max(y);
ipiv=i(jpiv);
jpiv=jpiv+k-1;
ipiv=ipiv+k-1;
Pk=I; Pk(ipiv,ipiv)=0; Pk(k,k)=0; Pk(k,ipiv)=1; Pk(ipiv,k)=1;
Qk=I; Qk(jpiv,jpiv)=0; Qk(k,k)=0; Qk(k,jpiv)=1; Qk(jpiv,k)=1;
return
