function int = newtcot(a,b,n,fun)
% NEWTCOT formule di Newton-Cotes.
% INT=NEWTCOT(A,B,N,FUN) calcola un'approssimazione dell'integrale della
% funzione FUN su (A,B) con una formula chiusa di Newton-Cotes a N nodi.
% FUN riceve in ingresso un vettore reale x e restituisce un vettore della
% stessa dimensione.
h=(b-a)/n;
n2=fix(n/2);
if n > 6, error('Il valore massimo di n e'' 6'); end
a03=1/3; a08=1/8; a45=1/45; a288=1/288; a140=1/140;
alpha=[0.5     0        0        0; ...
       a03     4*a03    0        0; ...
       3*a08   9*a08    0        0; ...
       14*a45  64*a45   24*a45   0; ...
       95*a288 375*a288 250*a288 0; ...
       41*a140 216*a140 27*a140  272*a140];
x=[a:h:b];
y=fun(x);
if size(y)==1
    dim=length(x);
    y=y.*ones(dim,1);
end
j1=[1:n2+1];  j2=[n2+2:n+1];
int=h*(sum(y(j1).*alpha(n,j1))+sum(y(j2).*alpha(n,n-j2+2)));
return
