function [xn,iter,root,itrefin]=newthorn(A,n,tol,x0,nmax,iref)
% NEWTHORN metodo di Newton-Horner con raffinamento.
%  [XN,ITER,ROOT,ITREFIN]=NEWTHORN(A,N,X0,TOL,NMAX,IREF) calcola
%  tutti gli zeri di un polinomio di grado N avente coefficienti
%  A(1),...,A(N). TOL specifica la tolleranza del metodo e X0 e` un dato iniziale.
%  NMAX specifica il numero massimo di iterazioni. Se IFLAG e` uguale a 1,
%  viene attivata la procedura di raffinamento.
apoly=A;
if iref==0, itrefin=[]; end
root=zeros(n,1);
for i=1:n, it=1; xn(it,i)=x0+sqrt(-1)*x0; err=tol+1; Ndeg=n-i+1;
    if Ndeg == 1
        it=it+1; xn(it,i)=-A(2)/A(1);
    else
        while it < nmax && err > tol
            [px,B]=horner(A,Ndeg,xn(it,i)); [pdx,C]=horner(B,Ndeg-1,xn(it,i));
            it=it+1;
            if pdx ~=0
                xn(it,i)=xn(it-1,i)-px/pdx;
                err=max(abs(xn(it,i)-xn(it-1,i)),abs(px));
            else
                fprintf(' Arresto causa annullamento derivata ');
                err=0; xn(it,i)=xn(it-1,i);
            end
        end
    end
    A=B;
    if iref==1
        alfa=xn(it,i); itr=1; err=tol+1;
        while err > tol*1e-3 && itr < nmax
           [px,B]=horner(apoly,n,alfa); [pdx,C]=horner(B,n-1,alfa);
           itr=itr+1;
           if pdx~=0
               alfa2=alfa-px/pdx;
               err=max(abs(alfa2-alfa),abs(px));
               alfa=alfa2;
           else
               fprintf(' Arresto causa annullamento derivata ');
               err=0;
           end
        end
        itrefin(i)=itr-1; xn(it,i)=alfa;
    end
    iter(i)=it-1; root(i)=xn(it,i); x0=root(i);
end
return
