function [x,iter,err]=newtonsys(F,J,x0,tol,nmax,p,varargin)
% NEWTONSYS metodo di Newton per sistemi non lineari.
% [X, ITER, ERR] = NEWTONSYS(F, J, X0, TOL, NMAX, P, MOL) risolve il sistema
% non lineare F(X)=0 con il metodo di Newton. F e J sono function handle associati
% alla funzione F ed allo Jacobiano.
% X0 specifica il vettore iniziale, TOL la tolleranza del metodo, NMAX il
% numero massimo delle iterazioni. P specifica il numero di passi consecutivi
% all'interno dei quali la Jacobiana e` mantenuta fissata.
% MOL e` la molteplicita` presunta della radice, se non inserita, si pone MOL=1.
% ITER e` l'iterazione alla quale la soluzione X e` calcolata. ERR e` il
% vettore delle norme degli incrementi
[n,m]=size(F);
if nargin==6
    mol=1;
else
    mol=varargin{1};
end
if n ~= m, error('Solo sistemi quadrati'); end
iter=0;  x=x0; err0=tol+1; err=err0;
Jxn=J(x);
[L,U,P]=lu(Jxn);
step=0;
while err0 > tol && iter< nmax
    Fxn=F(x);
    if step == p
        step = 0; Jxn=J(x);
        [L,U,P]=lu(Jxn);
    end
    iter=iter+1; step=step+1; Fxn=-P*Fxn;
    y=forwardcol(L,Fxn);
    deltax=backwardcol(U,y);
    x = x +  mol*deltax;
    err0=norm(mol*deltax); err=[err;err0];
end
return
