function [zero,iter,xvect,xdif,fx]=secant(fun,xm1,x0,tol,nmax)
% SECANT metodo delle secanti.
% [ZERO,ITER,XVECT,XDIF,FX]=SECANT(FUN,XM1,X0,TOL,NMAX) cerca lo zero di
% una funzione continua FUN nell'intervallo [A,B] usando il metodo delle secanti
% e partendo da X0 e XM1. TOL e NMAX specificano la tolleranza ed il massimo numero
% di iterazioni. FUN riceve in ingresso lo scalare x e restituisce un valore scalare reale.
% ZERO e` l'approssimazione della radice, ITER e` il numero di iterate svolte.
% XVECT e` il vettore delle iterate, XDIF il vettore delle differenze tra iterate
% successive, FX il vettore dei residui.
fxm1=fun(xm1);  fx0=fun(x0);
xvect=[xm1;x0]; fx=[fxm1;fx0];
err=tol+1; iter=0; xdif=[];
while iter < nmax && err > tol
    iter=iter+1;
    x=x0-fx0*(x0-xm1)/(fx0-fxm1);
    fnew=fun(x); xvect=[xvect;x]; fx=[fx;fnew];
    err=abs(x0-x); xdif=[xdif;err];
    xm1=x0; fxm1=fx0; x0=x; fx0=fnew;
end
zero=xvect(end);
return
