function [JSf,nodes]=simpadpt(fun,a,b,tol,hmin)
% SIMPADPT quadratura adattiva di Simpson.
% [JSF,NODES] = SIMPADPT(FUN,A,B,TOL,HMIN) fornisce un'approssimazione
% dell'integrale della funzione FUN au (A,B) a meno di un errore pari a TOL
% utilizzando in modo ricorsivo la quadratura adattiva di Simpson.
% La function FUN riceve in ingresso un vettore x e restituisce un vettore y
% della stessa dimensione di x.
% [JSF,NODES] = SIMPADPT(...) restituisce la distribuzione di nodi usati nel
% processo di quadratura.
A=[a,b]; N=[]; S=[]; JSf = 0; ba = 2*(b - a); nodes=[];
while ~isempty(A),
  [deltaI,ISc]=caldeltai(A,fun);
  if abs(deltaI) < 15*tol*(A(2)-A(1))/ba;
     JSf = JSf + ISc;    S = union(S,A);
     nodes = [nodes, A(1) (A(1)+A(2))*0.5 A(2)];
     S = [S(1), S(end)]; A = N; N = [];
  elseif A(2)-A(1) < hmin
     JSf=JSf+ISc;        S = union(S,A);
     S = [S(1), S(end)]; A=N; N=[];
     warning('Passo di integrazione troppo piccolo');
  else
     Am = (A(1)+A(2))*0.5;
     A = [A(1) Am];
     N = [Am, b];
  end
end
nodes=unique(nodes);
return

function [deltaI,ISc]=caldeltai(A,fun)
L=A(2)-A(1);
t=[0; 0.25; 0.5; 0.75; 1];
x=L*t+A(1);
L=L/6;
w=[1; 4; 1]; wp=[1;4;2;4;1];
fx=fun(x).*ones(5,1);
IS=L*sum(fx([1 3 5]).*w);
ISc=0.5*L*sum(fx.*wp);
deltaI=IS-ISc;
return
